@@ -32,6 +32,7 @@ from typing import Dict, Iterable, Optional, Type
 # 3rd party
 import click
 from consolekit.utils import abort
+from dom_toml.parser import BadConfigError
 from domdf_python_tools.words import Plural
 from packaging.requirements import InvalidRequirement
 from pyproject_parser.cli import ConfigTracebackHandler
@@ -48,12 +49,8 @@ _builder = Plural("builder", "builders")
 
 class WheyTracebackHandler(ConfigTracebackHandler):
 	"""
-	Custom :class:`consolekit.tracebacks.TracebackHandler` which handles :exc:`dom_toml.parser.BadConfigError`
-	and :exc:`packaging.requirements.InvalidRequirement`.
-	"""  # noqa: D400
-
-	def handle_InvalidRequirement(self, e: InvalidRequirement) -> bool:  # noqa: D102
-		raise abort(f"{e.__class__.__name__}: {e}", colour=False)
+	Custom :class:`consolekit.tracebacks.TracebackHandler`.
+	"""
 
 
 def parse_custom_builders(builders: Optional[Iterable[str]]) -> Dict[str, Type[AbstractBuilder]]:
